==> node-resque-0.16.3.tgz: package/test/core/scheduler.js <==
var specHelper = require(__dirname + "/../_specHelper.js").specHelper;
var should = require('should');

describe('scheduler', function(){

  var scheduler;
  var queue;

  it("can connect", function(done){
    scheduler = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, timeout: specHelper.timeout}, function(){
      should.exist(scheduler);
      done();
    });
  });

  it("can provide an error if connection failed", function(done) {
    // Only run this test if this is using real redis
    if(process.env.FAKEREDIS == 'true') {
      return done();
    }

    // Make a copy of the connectionDetails so we don't overwrite the original one
    var connectionDetails = {
      package:   specHelper.connectionDetails.package,
      host:      "wronghostname",
      password:  specHelper.connectionDetails.password,
      port:      "wrongport",
      database:  specHelper.connectionDetails.database,
      namespace: specHelper.connectionDetails.namespace,
    };

    var resolved = false;
    scheduler = new specHelper.NR.scheduler({connection: connectionDetails, timeout: specHelper.timeout}, function(err){
      if(resolved === false){ // new versions of redis will keep retrying in node v0.11x...
        should.exist(err);
        resolved = true;
        done();
      }
    });
  });

  describe('[with connection]', function() {
    before(function(done){
      specHelper.connect(function(){
        scheduler = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, timeout: specHelper.timeout}, function(){
          queue = new specHelper.NR.queue({connection: specHelper.connectionDetails, queue: specHelper.queue}, function(){
            done();
          });
        });
      });
    });

    beforeEach(function(done) {
      specHelper.cleanup(function(){
        done();
      });
    });

    after(function(done){
      specHelper.cleanup(function(){
        done();
      });
    });

    it("can boot", function(done){
      scheduler.start();
      done();
    });

    it('can be stopped', function(done){
      this.timeout(specHelper.timeout * 3);
      scheduler.end(function(){
        done();
      });
    });

    it("will move enqueued jobs when the time comes", function(done){
      queue.enqueueAt(1000 * 10, specHelper.queue, 'someJob', [1,2,3], function(){
        scheduler.poll(function(){
          specHelper.popFromQueue(function(err, obj){
            should.exist(obj);
            obj = JSON.parse(obj);
            obj['class'].should.equal('someJob');
            obj['args'].should.eql([1,2,3]);
            done();
          });
        });
      });
    });

    it("will not move jobs in the future", function(done){
      queue.enqueueAt((new Date().getTime() + 10000),  specHelper.queue, 'someJob', [1,2,3], function(){
        scheduler.poll(function(){
          specHelper.popFromQueue(function(err, obj){
            should.not.exist(obj);
            done();
          });
        });
      });
    });
  });

});

==> node-resque-0.17.0.tgz: package/test/core/scheduler.js <==
var specHelper = require(__dirname + "/../_specHelper.js").specHelper;
var should = require('should');

describe('scheduler', function(){

  var scheduler;
  var queue;

  it("can connect", function(done){
    scheduler = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, timeout: specHelper.timeout}, function(){
      should.exist(scheduler);
      done();
    });
  });

  it("can provide an error if connection failed", function(done) {
    // Only run this test if this is using real redis
    if(process.env.FAKEREDIS == 'true') {
      return done();
    }

    // Make a copy of the connectionDetails so we don't overwrite the original one
    var connectionDetails = {
      package:   specHelper.connectionDetails.package,
      host:      "wronghostname",
      password:  specHelper.connectionDetails.password,
      port:      "wrongport",
      database:  specHelper.connectionDetails.database,
      namespace: specHelper.connectionDetails.namespace,
    };

    var resolved = false;
    scheduler = new specHelper.NR.scheduler({connection: connectionDetails, timeout: specHelper.timeout}, function(err){
      if(resolved === false){ // new versions of redis will keep retrying in node v0.11x...
        should.exist(err);
        resolved = true;
        done();
      }
    });
  });

  describe('locking', function(){
    before(function(done){ specHelper.connect(done); });
    beforeEach(function(done){ specHelper.cleanup(done); });
    after(function(done){ specHelper.cleanup(done); });

    it('should only have one master; and can failover', function(done){
      sheduler_1 = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, name: 'scheduler_1', timeout: specHelper.timeout});
      sheduler_2 = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, name: 'scheduler_2', timeout: specHelper.timeout});

      sheduler_1.start();
      sheduler_2.start();

      setTimeout(function(){
        sheduler_1.master.should.equal(true);
        sheduler_2.master.should.equal(false);
        sheduler_1.end();
        setTimeout(function(){
          sheduler_1.master.should.equal(false);
          sheduler_2.master.should.equal(true);
          sheduler_2.end(function(){ done(); });
        }, (specHelper.timeout * 2));
      }, (specHelper.timeout * 2));
    });
  });

  describe('[with connection]', function() {
    before(function(done){
      specHelper.connect(function(){
        scheduler = new specHelper.NR.scheduler({connection: specHelper.connectionDetails, timeout: specHelper.timeout}, function(){
          queue = new specHelper.NR.queue({connection: specHelper.connectionDetails, queue: specHelper.queue}, function(){
            done();
          });
        });
      });
    });

    beforeEach(function(done){ specHelper.cleanup(done); });
    after(function(done){ specHelper.cleanup(done); });

    it("can boot", function(done){
      scheduler.start();
      done();
    });

    it('can be stopped', function(done){
      this.timeout(specHelper.timeout * 3);
      scheduler.end(function(){
        done();
      });
    });

    it("will move enqueued jobs when the time comes", function(done){
      queue.enqueueAt(1000 * 10, specHelper.queue, 'someJob', [1,2,3], function(){
        scheduler.poll(function(){
          specHelper.popFromQueue(function(err, obj){
            should.exist(obj);
            obj = JSON.parse(obj);
            obj['class'].should.equal('someJob');
            obj['args'].should.eql([1,2,3]);
            done();
          });
        });
      });
    });

    it("will not move jobs in the future", function(done){
      queue.enqueueAt((new Date().getTime() + 10000),  specHelper.queue, 'someJob', [1,2,3], function(){
        scheduler.poll(function(){
          specHelper.popFromQueue(function(err, obj){
            should.not.exist(obj);
            done();
          });
        });
      });
    });
  });

});
